diff --git a/src/blackgui/editors/interpolationsetupform.h b/src/blackgui/editors/interpolationsetupform.h
index ed9c6d21f..646a1c7a7 100644
--- a/src/blackgui/editors/interpolationsetupform.h
+++ b/src/blackgui/editors/interpolationsetupform.h
@@ -34,7 +34,7 @@ namespace BlackGui
explicit CInterpolationSetupForm(QWidget *parent = nullptr);
//! Destructor
- virtual ~CInterpolationSetupForm();
+ virtual ~CInterpolationSetupForm() override;
//! Set value
void setValue(const BlackMisc::Simulation::CInterpolationAndRenderingSetupBase &setup);
@@ -62,6 +62,9 @@ namespace BlackGui
//! Interpolator mode
void onInterpolatorModeChanged(bool checked);
+ //! Pitch entry
+ void onPitchChanged();
+
//! Mode from UI
BlackMisc::Simulation::CInterpolationAndRenderingSetupBase::InterpolatorMode getInterpolatorMode() const;
diff --git a/src/blackgui/editors/interpolationsetupform.ui b/src/blackgui/editors/interpolationsetupform.ui
index defbf190b..f3172f125 100644
--- a/src/blackgui/editors/interpolationsetupform.ui
+++ b/src/blackgui/editors/interpolationsetupform.ui
@@ -6,33 +6,26 @@
0
0
- 223
- 91
+ 277
+ 88
Frame
-
+
- 4
+ 0
- 4
+ 0
- 4
+ 0
- 4
+ 0
- -
-
-
- driver dbg. msgs.
-
-
-
-
@@ -40,6 +33,13 @@
+ -
+
+
+ driver dbg. msgs.
+
+
+
-
@@ -77,6 +77,44 @@
+ -
+
+
+ QFrame::NoFrame
+
+
+ QFrame::Raised
+
+
+
+ 0
+
+
+ 0
+
+
+ 0
+
+
+ 0
+
+
-
+
+
+ pitch on gnd.:
+
+
+
+ -
+
+
+ pitch on gnd.
+
+
+
+
+
+
-
@@ -129,12 +167,13 @@
rb_Spline
+ rb_Linear
cb_EnableParts
cb_SendGndFlagToSim
cb_FixSceneryOffset
cb_ForceVtolInterpolation
- cb_DebugDriver
cb_LogInterpolation
+ cb_DebugDriver
diff --git a/src/blackgui/editors/interpolationsetupform.cpp b/src/blackgui/editors/interpolationsetupform.cpp
index 4c32efc85..1faca7f40 100644
--- a/src/blackgui/editors/interpolationsetupform.cpp
+++ b/src/blackgui/editors/interpolationsetupform.cpp
@@ -12,6 +12,7 @@
#include "blackgui/guiutility.h"
using namespace BlackMisc;
+using namespace BlackMisc::PhysicalQuantities;
using namespace BlackMisc::Simulation;
namespace BlackGui
@@ -29,8 +30,11 @@ namespace BlackGui
connect(cb, &QCheckBox::stateChanged, this, &CInterpolationSetupForm::onCheckboxChanged);
}
// one conect is enough, otherwise 2 change signals
connect(ui->rb_Linear, &QRadioButton::toggled, this, &CInterpolationSetupForm::onInterpolatorModeChanged);
+
+ // pitch
+ connect(ui->le_PitchOnGround, &QLineEdit::editingFinished, this, &CInterpolationSetupForm::onPitchChanged);
}
CInterpolationSetupForm::~CInterpolationSetupForm()
@@ -44,6 +48,7 @@ namespace BlackGui
ui->cb_ForceVtolInterpolation->setChecked(setup.isForcingVtolInterpolation());
ui->cb_SendGndFlagToSim->setChecked(setup.isSendingGndFlagToSimulator());
ui->cb_FixSceneryOffset->setChecked(setup.isFixingSceneryOffset());
+ ui->le_PitchOnGround->setText(setup.getPitchOnGround().valueRoundedWithUnit(CAngleUnit::deg()));
this->setInterpolatorMode(setup.getInterpolatorMode());
}
@@ -107,5 +112,12 @@ namespace BlackGui
Q_UNUSED(checked);
emit this->valueChanged();
}
+
+ void CInterpolationSetupForm::onPitchChanged()
+ {
+ const QString p = ui->le_PitchOnGround->text().trimmed();
+ CAngle pitch;
+ pitch.parseFromString(p);
+ }
} // ns
} // ns
@@ -29,8 +30,11 @@ namespace BlackGui
connect(cb, &QCheckBox::stateChanged, this, &CInterpolationSetupForm::onCheckboxChanged);
}
- // one conect is enough, otherwise 2 change signals
+ // one connect is enough, otherwise 2 change signals
connect(ui->rb_Linear, &QRadioButton::toggled, this, &CInterpolationSetupForm::onInterpolatorModeChanged);